# coding: utf-8

"""
    DLRN API

    DLRN API client

    OpenAPI spec version: 1.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import setuptools

setuptools.setup(
    setup_requires=['pbr'],
    pbr=True)
